#! /usr/bin/env dcli

import 'dart:io';

import 'package:dcli/dcli.dart';
import 'package:onepub/src/onepub_settings.dart';
import 'package:onepub/src/util/one_pub_token_store.dart';

import '../../../test/src/test_settings.dart';

/// dcli script generated by:
/// dcli create %scriptname%
///
/// See
/// https://pub.dev/packages/dcli#-installing-tab-
///
/// For details on installing dcli.
///
void main(List<String> args) {
  final pathToBin = DartProject.self.pathToBinDir;

  final pathToOnePubExe = join(pathToBin, 'onepub.dart');

  withTestSettings((testSettings) {
    final user = testSettings.member;

    print('Please login with the $user account');

    /// prompt the user to login inot onepub.
    '$pathToOnePubExe login'.run;
    // we need to force a reload of OnePubSettings
    // as the login will have updated it.
    withSettings(() {
      final tokenStore = OnePubTokenStore();
      if (!tokenStore.isLoggedIn) {
        printerr(red('Login Failed. Tests run stopped'));
        exit(1);
      }

      final onepubSettings = OnePubSettings.use;
      final url = onepubSettings.onepubHostedUrl();
      final credentials = tokenStore.tokenStore.findCredential(url);

      if (credentials == null) {
        printerr(red('Unable to find the OnePub token for $url'));
        exit(1);
      }

      final onePubToken = credentials.token;

      testSettings
        ..onepubToken = onePubToken!
        ..save();
    });
  }, forAuthentication: true);
}
